<?php

namespace Drupal\client_connection\Resolver;

/**
 * Defines the interface for connection resolvers.
 */
interface ConnectionResolverInterface {

  /**
   * Resolves the connection configuration.
   *
   * @param string $plugin_id
   *   The plugin ID to resolve configuration for.
   * @param \Drupal\Core\Plugin\Context\ContextInterface[] $contexts
   *   Available contextual information to help resolve the configuration.
   * @param string $channel_id
   *   The channel "track" id to resolve configuration for. Useful to help some
   *   resolvers return or not return relevant configuration.
   *
   * @return \Drupal\client_connection\Entity\ClientConnectionConfigInterface|null
   *   The client connection configuration, if resolved. Otherwise NULL,
   *   indicating that the next resolver in the chain should be called.
   */
  public function resolve($plugin_id, array $contexts, $channel_id = 'site');

}
